@@ -13,7 +13,6 @@ prep_om_data_frame <- function(df) {
 
   colnames(df) <- stringr::str_to_upper(colnames(df))
 
-
   if("EXCLUSION" %in% colnames(df) & sum(grepl(x = df$EXCLUSION, "clude")) > 1){
     df <- df %>%
       dplyr::rename(COHORTSTATUS = .data$EXCLUSION)
@@ -34,5 +33,10 @@ prep_om_data_frame <- function(df) {
     warning("Please use the CohortStatus column with values of 'Include' or 'Exclude' to indicate exclusions.")
   }
 
+  mult_rows <- df %>% dplyr::count(.data$STUDENTID) %>% dplyr::filter(n > 1)
+  if (nrow(mult_rows) >  0) {
+    warning(paste0("IPEDS requests highest degree only for each student in each award year. These StudentIds may have multiple degree levels: ", toString(unique(mult_rows$STUDENTID))))
+  }
+
   return(df)
 }
