@@ -1,23 +1,23 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
 
-## ----setup, eval=FALSE, echo=FALSE--------------------------------------------
-#  library(IPEDSuploadables)
+## ----setup, include=FALSE-----------------------------------------------------
+library(IPEDSuploadables)
 
 ## ----dataprep, echo=FALSE, eval=FALSE, message=FALSE--------------------------
-#  #export spreadsheet with specs from google drive
-#  #read in with readr
-#  specs_OM <- googlesheets4::read_sheet('1e1o9Omor7jWwxKRncgzvFbz67sUxKqSkPtSW_B-8jr0')
-#  #then run
-#  use_data(specs_OM, overwrite = TRUE) #to save as .rda and replace the old file
-#  
+# #this chunk is only used during interactive session by the package maintainers, if the requirements have been updated
+# 
+# tryCatch(specs_OM <- googlesheets4::read_sheet('1e1o9Omor7jWwxKRncgzvFbz67sUxKqSkPtSW_B-8jr0'),
+#         error = function(x) message("Google Sheet unavailable"),
+#         warning = function(y) message("There was a warning"))
+# #then run
+# use_data(specs_OM, overwrite = TRUE) #to save as .rda and replace the old file
+# 
 
 ## ----specstable, echo=FALSE, warning=FALSE, message=FALSE---------------------
-#figure out why striped isn't working when format = 'html'
-load("../data/specs_OM.rda")
 library(magrittr)
 specs_OM$ACCEPTABLE_VALUES <- stringr::str_replace_all(specs_OM$ACCEPTABLE_VALUES, pattern = "\\n", replacement = "<br>")
 knitr::kable(specs_OM, 
